@@ -23,7 +23,7 @@ from featuretools.utils.gen_utils import (
     is_instance
 )
 
-ks = import_or_none('databricks.koalas')
+ps = import_or_none('pyspark.pandas')
 
 
 class FeatureSetCalculator(object):
@@ -153,7 +153,7 @@ class FeatureSetCalculator(object):
         for feat in self.feature_set.target_features:
             column_list.extend(feat.get_feature_names())
 
-        if is_instance(df, (dd, ks), 'DataFrame'):
+        if is_instance(df, (dd, ps), 'DataFrame'):
             column_list.extend([target_dataframe.ww.index])
 
         return df[column_list]
@@ -554,7 +554,7 @@ class FeatureSetCalculator(object):
 
         # merge the identity feature from the parent dataframe into the child
         merge_df = parent_df[list(col_map.keys())].rename(columns=col_map)
-        if is_instance(merge_df, (dd, ks), 'DataFrame'):
+        if is_instance(merge_df, (dd, ps), 'DataFrame'):
             new_df = child_df.merge(merge_df, left_on=merge_col, right_on=merge_col,
                                     how='left')
         else:
@@ -642,8 +642,8 @@ class FeatureSetCalculator(object):
                         to_agg[column_id] = []
                     if isinstance(base_frame, dd.DataFrame):
                         func = f.get_function(agg_type=Library.DASK)
-                    elif is_instance(base_frame, ks, 'DataFrame'):
-                        func = f.get_function(agg_type=Library.KOALAS)
+                    elif is_instance(base_frame, ps, 'DataFrame'):
+                        func = f.get_function(agg_type=Library.SPARK)
                     else:
                         func = f.get_function()
 
@@ -701,7 +701,7 @@ class FeatureSetCalculator(object):
                 # to silence pandas warning about ambiguity we explicitly pass
                 # the column (in actuality grouping by both index and group would
                 # work)
-                if is_instance(base_frame, (dd, ks), 'DataFrame'):
+                if is_instance(base_frame, (dd, ps), 'DataFrame'):
                     to_merge = base_frame.groupby(groupby_col).agg(to_agg)
 
                 else:
@@ -720,7 +720,7 @@ class FeatureSetCalculator(object):
                     categories = pdtypes.CategoricalDtype(categories=frame.index.categories)
                     to_merge.index = to_merge.index.astype(object).astype(categories)
 
-                if is_instance(frame, (dd, ks), 'DataFrame'):
+                if is_instance(frame, (dd, ps), 'DataFrame'):
                     frame = frame.merge(to_merge, left_on=parent_merge_col, right_index=True, how='left')
                 else:
                     frame = pd.merge(left=frame, right=to_merge,
