@@ -33,11 +33,11 @@ class Count(AggregationPrimitive):
     return_type = ColumnSchema(logical_type=IntegerNullable, semantic_tags={'numeric'})
     stack_on_self = False
     default_value = 0
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the number"
 
     def get_function(self, agg_type=Library.PANDAS):
-        if agg_type in [Library.DASK, Library.KOALAS]:
+        if agg_type in [Library.DASK, Library.SPARK]:
             return 'count'
 
         return pd.Series.count
@@ -62,11 +62,11 @@ class Sum(AggregationPrimitive):
     stack_on_self = False
     stack_on_exclude = [Count]
     default_value = 0
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = 'the sum of {}'
 
     def get_function(self, agg_type=Library.PANDAS):
-        if agg_type in [Library.DASK, Library.KOALAS]:
+        if agg_type in [Library.DASK, Library.SPARK]:
             return 'sum'
 
         return np.sum
@@ -93,14 +93,14 @@ class Mean(AggregationPrimitive):
     name = "mean"
     input_types = [ColumnSchema(semantic_tags={'numeric'})]
     return_type = ColumnSchema(semantic_tags={'numeric'})
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the average of {}"
 
     def __init__(self, skipna=True):
         self.skipna = skipna
 
     def get_function(self, agg_type=Library.PANDAS):
-        if agg_type in [Library.DASK, Library.KOALAS]:
+        if agg_type in [Library.DASK, Library.SPARK]:
             return 'mean'
 
         if self.skipna:
@@ -150,11 +150,11 @@ class Min(AggregationPrimitive):
     input_types = [ColumnSchema(semantic_tags={'numeric'})]
     return_type = ColumnSchema(semantic_tags={'numeric'})
     stack_on_self = False
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the minimum of {}"
 
     def get_function(self, agg_type=Library.PANDAS):
-        if agg_type in [Library.DASK, Library.KOALAS]:
+        if agg_type in [Library.DASK, Library.SPARK]:
             return 'min'
 
         return np.min
@@ -172,11 +172,11 @@ class Max(AggregationPrimitive):
     input_types = [ColumnSchema(semantic_tags={'numeric'})]
     return_type = ColumnSchema(semantic_tags={'numeric'})
     stack_on_self = False
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the maximum of {}"
 
     def get_function(self, agg_type=Library.PANDAS):
-        if agg_type in [Library.DASK, Library.KOALAS]:
+        if agg_type in [Library.DASK, Library.SPARK]:
             return 'max'
 
         return np.max
@@ -199,7 +199,7 @@ class NumUnique(AggregationPrimitive):
     input_types = [ColumnSchema(semantic_tags={'category'})]
     return_type = ColumnSchema(logical_type=IntegerNullable, semantic_tags={'numeric'})
     stack_on_self = False
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the number of unique elements in {}"
 
     def get_function(self, agg_type=Library.PANDAS):
@@ -221,7 +221,7 @@ class NumUnique(AggregationPrimitive):
 
             return dd.Aggregation(self.name, chunk=chunk, agg=agg, finalize=finalize)
 
-        elif agg_type == Library.KOALAS:
+        elif agg_type == Library.SPARK:
             return 'nunique'
 
         return pd.Series.nunique
@@ -484,11 +484,11 @@ class Std(AggregationPrimitive):
     input_types = [ColumnSchema(semantic_tags={'numeric'})]
     return_type = ColumnSchema(semantic_tags={'numeric'})
     stack_on_self = False
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the standard deviation of {}"
 
     def get_function(self, agg_type=Library.PANDAS):
-        if agg_type in [Library.DASK, Library.KOALAS]:
+        if agg_type in [Library.DASK, Library.SPARK]:
             return 'std'
 
         return np.std
