@@ -1,17 +1,12 @@
 import numpy as np
 import pandas as pd
+from woodwork.column_schema import ColumnSchema
+from woodwork.logical_types import Boolean, BooleanNullable, Datetime, Ordinal
 
 from featuretools.primitives.base.transform_primitive_base import (
     TransformPrimitive
 )
 from featuretools.utils.gen_utils import Library
-from featuretools.variable_types import (
-    Boolean,
-    Datetime,
-    Numeric,
-    Ordinal,
-    Variable
-)
 
 
 class GreaterThan(TransformPrimitive):
@@ -28,8 +23,10 @@ class GreaterThan(TransformPrimitive):
         [True, False, False]
     """
     name = "greater_than"
-    input_types = [[Numeric, Numeric], [Datetime, Datetime], [Ordinal, Ordinal]]
-    return_type = Boolean
+    input_types = [[ColumnSchema(semantic_tags={'numeric'}), ColumnSchema(semantic_tags={'numeric'})],
+                   [ColumnSchema(logical_type=Datetime), ColumnSchema(logical_type=Datetime)],
+                   [ColumnSchema(logical_type=Ordinal), ColumnSchema(logical_type=Ordinal)]]
+    return_type = ColumnSchema(logical_type=BooleanNullable)
     compatibility = [Library.PANDAS, Library.DASK]
     description_template = "whether {} is greater than {}"
 
@@ -54,9 +51,11 @@ class GreaterThanScalar(TransformPrimitive):
         [True, False, False]
     """
     name = "greater_than_scalar"
-    input_types = [[Numeric], [Datetime], [Ordinal]]
-    return_type = Boolean
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    input_types = [[ColumnSchema(semantic_tags={'numeric'})],
+                   [ColumnSchema(logical_type=Datetime)],
+                   [ColumnSchema(logical_type=Ordinal)]]
+    return_type = ColumnSchema(logical_type=BooleanNullable)
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
 
     def __init__(self, value=0):
         self.value = value
@@ -85,9 +84,11 @@ class GreaterThanEqualTo(TransformPrimitive):
         [True, False, True]
     """
     name = "greater_than_equal_to"
-    input_types = [[Numeric, Numeric], [Datetime, Datetime], [Ordinal, Ordinal]]
-    return_type = Boolean
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    input_types = [[ColumnSchema(semantic_tags={'numeric'}), ColumnSchema(semantic_tags={'numeric'})],
+                   [ColumnSchema(logical_type=Datetime), ColumnSchema(logical_type=Datetime)],
+                   [ColumnSchema(logical_type=Ordinal), ColumnSchema(logical_type=Ordinal)]]
+    return_type = ColumnSchema(logical_type=BooleanNullable)
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "whether {} is greater than or equal to {}"
 
     def get_function(self):
@@ -111,9 +112,11 @@ class GreaterThanEqualToScalar(TransformPrimitive):
         [True, False, True]
     """
     name = "greater_than_equal_to_scalar"
-    input_types = [[Numeric], [Datetime], [Ordinal]]
-    return_type = Boolean
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    input_types = [[ColumnSchema(semantic_tags={'numeric'})],
+                   [ColumnSchema(logical_type=Datetime)],
+                   [ColumnSchema(logical_type=Ordinal)]]
+    return_type = ColumnSchema(logical_type=BooleanNullable)
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
 
     def __init__(self, value=0):
         self.value = value
@@ -142,9 +145,11 @@ class LessThan(TransformPrimitive):
         [False, True, False]
     """
     name = "less_than"
-    input_types = [[Numeric, Numeric], [Datetime, Datetime], [Ordinal, Ordinal]]
-    return_type = Boolean
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    input_types = [[ColumnSchema(semantic_tags={'numeric'}), ColumnSchema(semantic_tags={'numeric'})],
+                   [ColumnSchema(logical_type=Datetime), ColumnSchema(logical_type=Datetime)],
+                   [ColumnSchema(logical_type=Ordinal), ColumnSchema(logical_type=Ordinal)]]
+    return_type = ColumnSchema(logical_type=BooleanNullable)
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "whether {} is less than {}"
 
     def get_function(self):
@@ -168,9 +173,11 @@ class LessThanScalar(TransformPrimitive):
         [False, True, False]
     """
     name = "less_than_scalar"
-    input_types = [[Numeric], [Datetime], [Ordinal]]
-    return_type = Boolean
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    input_types = [[ColumnSchema(semantic_tags={'numeric'})],
+                   [ColumnSchema(logical_type=Datetime)],
+                   [ColumnSchema(logical_type=Ordinal)]]
+    return_type = ColumnSchema(logical_type=BooleanNullable)
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
 
     def __init__(self, value=0):
         self.value = value
@@ -199,9 +206,11 @@ class LessThanEqualTo(TransformPrimitive):
         [False, True, True]
     """
     name = "less_than_equal_to"
-    input_types = [[Numeric, Numeric], [Datetime, Datetime], [Ordinal, Ordinal]]
-    return_type = Boolean
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    input_types = [[ColumnSchema(semantic_tags={'numeric'}), ColumnSchema(semantic_tags={'numeric'})],
+                   [ColumnSchema(logical_type=Datetime), ColumnSchema(logical_type=Datetime)],
+                   [ColumnSchema(logical_type=Ordinal), ColumnSchema(logical_type=Ordinal)]]
+    return_type = ColumnSchema(logical_type=BooleanNullable)
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "whether {} is less than or equal to {}"
 
     def get_function(self):
@@ -225,9 +234,11 @@ class LessThanEqualToScalar(TransformPrimitive):
         [False, True, True]
     """
     name = "less_than_equal_to_scalar"
-    input_types = [[Numeric], [Datetime], [Ordinal]]
-    return_type = Boolean
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    input_types = [[ColumnSchema(semantic_tags={'numeric'})],
+                   [ColumnSchema(logical_type=Datetime)],
+                   [ColumnSchema(logical_type=Ordinal)]]
+    return_type = ColumnSchema(logical_type=BooleanNullable)
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
 
     def __init__(self, value=0):
         self.value = value
@@ -256,10 +267,10 @@ class Equal(TransformPrimitive):
         [False, False, True]
     """
     name = "equal"
-    input_types = [Variable, Variable]
-    return_type = Boolean
+    input_types = [ColumnSchema(), ColumnSchema()]
+    return_type = ColumnSchema(logical_type=BooleanNullable)
     commutative = True
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "whether {} equals {}"
 
     def get_function(self):
@@ -290,9 +301,9 @@ class EqualScalar(TransformPrimitive):
         [False, False, True]
     """
     name = "equal_scalar"
-    input_types = [Variable]
-    return_type = Boolean
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    input_types = [ColumnSchema()]
+    return_type = ColumnSchema(logical_type=BooleanNullable)
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
 
     def __init__(self, value=None):
         self.value = value
@@ -321,8 +332,8 @@ class NotEqual(TransformPrimitive):
         [True, True, False]
     """
     name = "not_equal"
-    input_types = [Variable, Variable]
-    return_type = Boolean
+    input_types = [ColumnSchema(), ColumnSchema()]
+    return_type = ColumnSchema(logical_type=BooleanNullable)
     commutative = True
     compatibility = [Library.PANDAS, Library.DASK]
     description_template = "whether {} does not equal {}"
@@ -355,9 +366,9 @@ class NotEqualScalar(TransformPrimitive):
         [True, True, False]
     """
     name = "not_equal_scalar"
-    input_types = [Variable]
-    return_type = Boolean
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    input_types = [ColumnSchema()]
+    return_type = ColumnSchema(logical_type=BooleanNullable)
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
 
     def __init__(self, value=None):
         self.value = value
@@ -386,10 +397,10 @@ class AddNumeric(TransformPrimitive):
         [3, 3, 4]
     """
     name = "add_numeric"
-    input_types = [Numeric, Numeric]
-    return_type = Numeric
+    input_types = [ColumnSchema(semantic_tags={'numeric'}), ColumnSchema(semantic_tags={'numeric'})]
+    return_type = ColumnSchema(semantic_tags={'numeric'})
     commutative = True
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the sum of {} and {}"
 
     def get_function(self):
@@ -412,9 +423,9 @@ class AddNumericScalar(TransformPrimitive):
         [5, 3, 4]
     """
     name = "add_numeric_scalar"
-    input_types = [Numeric]
-    return_type = Numeric
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    input_types = [ColumnSchema(semantic_tags={'numeric'})]
+    return_type = ColumnSchema(semantic_tags={'numeric'})
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
 
     def __init__(self, value=0):
         self.value = value
@@ -448,8 +459,8 @@ class SubtractNumeric(TransformPrimitive):
         [1, -1, 0]
     """
     name = "subtract_numeric"
-    input_types = [Numeric, Numeric]
-    return_type = Numeric
+    input_types = [ColumnSchema(semantic_tags={'numeric'}), ColumnSchema(semantic_tags={'numeric'})]
+    return_type = ColumnSchema(semantic_tags={'numeric'})
     compatibility = [Library.PANDAS, Library.DASK]
     description_template = "the result of {} minus {}"
 
@@ -476,9 +487,9 @@ class SubtractNumericScalar(TransformPrimitive):
         [1, -1, 0]
     """
     name = "subtract_numeric_scalar"
-    input_types = [Numeric]
-    return_type = Numeric
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    input_types = [ColumnSchema(semantic_tags={'numeric'})]
+    return_type = ColumnSchema(semantic_tags={'numeric'})
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
 
     def __init__(self, value=0):
         self.value = value
@@ -507,9 +518,9 @@ class ScalarSubtractNumericFeature(TransformPrimitive):
         [-1, 1, 0]
     """
     name = "scalar_subtract_numeric_feature"
-    input_types = [Numeric]
-    return_type = Numeric
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    input_types = [ColumnSchema(semantic_tags={'numeric'})]
+    return_type = ColumnSchema(semantic_tags={'numeric'})
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
 
     def __init__(self, value=0):
         self.value = value
@@ -539,13 +550,15 @@ class MultiplyNumeric(TransformPrimitive):
     """
     name = "multiply_numeric"
     input_types = [
-        [Numeric, Numeric],
-        [Numeric, Boolean],
-        [Boolean, Numeric],
+        [ColumnSchema(semantic_tags={'numeric'}), ColumnSchema(semantic_tags={'numeric'})],
+        [ColumnSchema(semantic_tags={'numeric'}), ColumnSchema(logical_type=Boolean)],
+        [ColumnSchema(logical_type=Boolean), ColumnSchema(semantic_tags={'numeric'})],
+        [ColumnSchema(semantic_tags={'numeric'}), ColumnSchema(logical_type=BooleanNullable)],
+        [ColumnSchema(logical_type=BooleanNullable), ColumnSchema(semantic_tags={'numeric'})],
     ]
-    return_type = Numeric
+    return_type = ColumnSchema(semantic_tags={'numeric'})
     commutative = True
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the product of {} and {}"
 
     def get_function(self):
@@ -568,9 +581,9 @@ class MultiplyNumericScalar(TransformPrimitive):
         [6, 2, 4]
     """
     name = "multiply_numeric_scalar"
-    input_types = [Numeric]
-    return_type = Numeric
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    input_types = [ColumnSchema(semantic_tags={'numeric'})]
+    return_type = ColumnSchema(semantic_tags={'numeric'})
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
 
     def __init__(self, value=1):
         self.value = value
@@ -599,9 +612,11 @@ class MultiplyBoolean(TransformPrimitive):
         [True, False, False]
     """
     name = "multiply_boolean"
-    input_types = [[Boolean, Boolean]]
-
-    return_type = Boolean
+    input_types = [[ColumnSchema(logical_type=BooleanNullable), ColumnSchema(logical_type=BooleanNullable)],
+                   [ColumnSchema(logical_type=Boolean), ColumnSchema(logical_type=Boolean)],
+                   [ColumnSchema(logical_type=Boolean), ColumnSchema(logical_type=BooleanNullable)],
+                   [ColumnSchema(logical_type=BooleanNullable), ColumnSchema(logical_type=Boolean)]]
+    return_type = ColumnSchema(logical_type=BooleanNullable)
     commutative = True
     compatibility = [Library.PANDAS, Library.DASK]
     description_template = "the product of {} and {}"
@@ -632,9 +647,9 @@ class DivideNumeric(TransformPrimitive):
         [2.0, 0.5, 1.0]
     """
     name = "divide_numeric"
-    input_types = [Numeric, Numeric]
-    return_type = Numeric
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    input_types = [ColumnSchema(semantic_tags={'numeric'}), ColumnSchema(semantic_tags={'numeric'})]
+    return_type = ColumnSchema(semantic_tags={'numeric'})
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the result of {} divided by {}"
 
     def __init__(self, commutative=False):
@@ -660,9 +675,9 @@ class DivideNumericScalar(TransformPrimitive):
         [1.5, 0.5, 1.0]
     """
     name = "divide_numeric_scalar"
-    input_types = [Numeric]
-    return_type = Numeric
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    input_types = [ColumnSchema(semantic_tags={'numeric'})]
+    return_type = ColumnSchema(semantic_tags={'numeric'})
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
 
     def __init__(self, value=1):
         self.value = value
@@ -691,9 +706,9 @@ class DivideByFeature(TransformPrimitive):
         [0.5, 2.0, 1.0]
     """
     name = "divide_by_feature"
-    input_types = [Numeric]
-    return_type = Numeric
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    input_types = [ColumnSchema(semantic_tags={'numeric'})]
+    return_type = ColumnSchema(semantic_tags={'numeric'})
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
 
     def __init__(self, value=1):
         self.value = value
@@ -722,9 +737,9 @@ class ModuloNumeric(TransformPrimitive):
         [0, 1, 1]
     """
     name = "modulo_numeric"
-    input_types = [Numeric, Numeric]
-    return_type = Numeric
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    input_types = [ColumnSchema(semantic_tags={'numeric'}), ColumnSchema(semantic_tags={'numeric'})]
+    return_type = ColumnSchema(semantic_tags={'numeric'})
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the remainder after dividing {} by {}"
 
     def get_function(self):
@@ -748,9 +763,9 @@ class ModuloNumericScalar(TransformPrimitive):
         [1, 1, 0]
     """
     name = "modulo_numeric_scalar"
-    input_types = [Numeric]
-    return_type = Numeric
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    input_types = [ColumnSchema(semantic_tags={'numeric'})]
+    return_type = ColumnSchema(semantic_tags={'numeric'})
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
 
     def __init__(self, value=1):
         self.value = value
@@ -779,9 +794,9 @@ class ModuloByFeature(TransformPrimitive):
         [2, 0, 0]
     """
     name = "modulo_by_feature"
-    input_types = [Numeric]
-    return_type = Numeric
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    input_types = [ColumnSchema(semantic_tags={'numeric'})]
+    return_type = ColumnSchema(semantic_tags={'numeric'})
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
 
     def __init__(self, value=1):
         self.value = value
@@ -810,10 +825,13 @@ class And(TransformPrimitive):
         [False, True, False]
     """
     name = "and"
-    input_types = [Boolean, Boolean]
-    return_type = Boolean
+    input_types = [[ColumnSchema(logical_type=BooleanNullable), ColumnSchema(logical_type=BooleanNullable)],
+                   [ColumnSchema(logical_type=Boolean), ColumnSchema(logical_type=Boolean)],
+                   [ColumnSchema(logical_type=Boolean), ColumnSchema(logical_type=BooleanNullable)],
+                   [ColumnSchema(logical_type=BooleanNullable), ColumnSchema(logical_type=Boolean)]]
+    return_type = ColumnSchema(logical_type=BooleanNullable)
     commutative = True
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "whether {} and {} are true"
 
     def get_function(self):
@@ -837,10 +855,13 @@ class Or(TransformPrimitive):
         [True, True, False]
     """
     name = "or"
-    input_types = [Boolean, Boolean]
-    return_type = Boolean
+    input_types = [[ColumnSchema(logical_type=BooleanNullable), ColumnSchema(logical_type=BooleanNullable)],
+                   [ColumnSchema(logical_type=Boolean), ColumnSchema(logical_type=Boolean)],
+                   [ColumnSchema(logical_type=Boolean), ColumnSchema(logical_type=BooleanNullable)],
+                   [ColumnSchema(logical_type=BooleanNullable), ColumnSchema(logical_type=Boolean)]]
+    return_type = ColumnSchema(logical_type=BooleanNullable)
     commutative = True
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "whether {} is true or {} is true"
 
     def get_function(self):
