@@ -6,6 +6,7 @@ from woodwork.logical_types import (
     Boolean,
     BooleanNullable,
     Categorical,
+    Double,
     EmailAddress,
     NaturalLanguage
 )
@@ -26,7 +27,7 @@ class IsNull(TransformPrimitive):
     name = "is_null"
     input_types = [ColumnSchema()]
     return_type = ColumnSchema(logical_type=Boolean)
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "whether {} is null"
 
     def get_function(self):
@@ -46,13 +47,103 @@ class Absolute(TransformPrimitive):
     name = "absolute"
     input_types = [ColumnSchema(semantic_tags={'numeric'})]
     return_type = ColumnSchema(semantic_tags={'numeric'})
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the absolute value of {}"
 
     def get_function(self):
         return np.absolute
 
 
+class SquareRoot(TransformPrimitive):
+    """Computes the square root of a number.
+
+    Examples:
+        >>> sqrt = SquareRoot()
+        >>> sqrt([9.0, 16.0, 4.0]).tolist()
+        [3.0, 4.0, 2.0]
+    """
+    name = "square_root"
+    input_types = [ColumnSchema(semantic_tags={'numeric'})]
+    return_type = ColumnSchema(logical_type=Double, semantic_tags={'numeric'})
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
+    description_template = "the square root of {}"
+
+    def get_function(self):
+        return np.sqrt
+
+
+class NaturalLogarithm(TransformPrimitive):
+    """Computes the natural logarithm of a number.
+
+    Examples:
+        >>> log = NaturalLogarithm()
+        >>> log([1.0, np.e]).tolist()
+        [0.0, 1.0]
+    """
+    name = "natural_logarithm"
+    input_types = [ColumnSchema(semantic_tags={'numeric'})]
+    return_type = ColumnSchema(logical_type=Double, semantic_tags={'numeric'})
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
+    description_template = "the natural logarithm of {}"
+
+    def get_function(self):
+        return np.log
+
+
+class Sine(TransformPrimitive):
+    """Computes the sine of a number.
+
+    Examples:
+        >>> sin = Sine()
+        >>> sin([-np.pi/2.0, 0.0, np.pi/2.0]).tolist()
+        [-1.0, 0.0, 1.0]
+    """
+    name = "sine"
+    input_types = [ColumnSchema(semantic_tags={'numeric'})]
+    return_type = ColumnSchema(logical_type=Double, semantic_tags={'numeric'})
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
+    description_template = "the sine of {}"
+
+    def get_function(self):
+        return np.sin
+
+
+class Cosine(TransformPrimitive):
+    """Computes the cosine of a number.
+
+    Examples:
+        >>> cos = Cosine()
+        >>> cos([0.0, np.pi/2.0, np.pi]).tolist()
+        [1.0, 6.123233995736766e-17, -1.0]
+    """
+    name = "cosine"
+    input_types = [ColumnSchema(semantic_tags={'numeric'})]
+    return_type = ColumnSchema(logical_type=Double, semantic_tags={'numeric'})
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
+    description_template = "the cosine of {}"
+
+    def get_function(self):
+        return np.cos
+
+
+class Tangent(TransformPrimitive):
+    """Computes the tangent of a number.
+
+    Examples:
+        >>> tan = Tangent()
+        >>> tan([-np.pi, 0.0, np.pi/2.0]).tolist()
+        [1.2246467991473532e-16, 0.0, 1.633123935319537e+16]
+    """
+    name = "tangent"
+    input_types = [ColumnSchema(semantic_tags={'numeric'})]
+    return_type = ColumnSchema(logical_type=Double, semantic_tags={'numeric'})
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
+    description_template = "the tangent of {}"
+
+    def get_function(self):
+        return np.tan
+
+
 class NumCharacters(TransformPrimitive):
     """Calculates the number of characters in a string.
 
@@ -66,7 +157,7 @@ class NumCharacters(TransformPrimitive):
     name = 'num_characters'
     input_types = [ColumnSchema(logical_type=NaturalLanguage)]
     return_type = ColumnSchema(semantic_tags={'numeric'})
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the number of characters in {}"
 
     def get_function(self):
@@ -89,7 +180,7 @@ class NumWords(TransformPrimitive):
     name = 'num_words'
     input_types = [ColumnSchema(logical_type=NaturalLanguage)]
     return_type = ColumnSchema(semantic_tags={'numeric'})
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the number of words in {}"
 
     def get_function(self):
@@ -110,7 +201,7 @@ class IsIn(TransformPrimitive):
     name = "isin"
     input_types = [ColumnSchema()]
     return_type = ColumnSchema(logical_type=Boolean)
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
 
     def __init__(self, list_of_outputs=None):
         self.list_of_outputs = list_of_outputs
@@ -169,7 +260,7 @@ class Negate(TransformPrimitive):
     name = "negate"
     input_types = [ColumnSchema(semantic_tags={'numeric'})]
     return_type = ColumnSchema(semantic_tags={'numeric'})
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the negation of {}"
 
     def get_function(self):
@@ -192,7 +283,7 @@ class Not(TransformPrimitive):
     name = "not"
     input_types = [[ColumnSchema(logical_type=Boolean)], [ColumnSchema(logical_type=BooleanNullable)]]
     return_type = ColumnSchema(logical_type=BooleanNullable)
-    compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the negation of {}"
 
     def generate_name(self, base_feature_names):
