@@ -45,27 +45,27 @@ def get_transform_primitives():
 def list_primitives():
     trans_names, trans_primitives, valid_inputs, return_type = _get_names_primitives(get_transform_primitives)
     trans_dask = [Library.DASK in primitive.compatibility for primitive in trans_primitives]
-    trans_koalas = [Library.KOALAS in primitive.compatibility for primitive in trans_primitives]
+    trans_spark = [Library.SPARK in primitive.compatibility for primitive in trans_primitives]
     transform_df = pd.DataFrame({'name': trans_names,
                                  'description': _get_descriptions(trans_primitives),
                                  'dask_compatible': trans_dask,
-                                 'koalas_compatible': trans_koalas,
+                                 'spark_compatible': trans_spark,
                                  'valid_inputs': valid_inputs,
                                  'return_type': return_type})
     transform_df['type'] = 'transform'
 
     agg_names, agg_primitives, valid_inputs, return_type = _get_names_primitives(get_aggregation_primitives)
     agg_dask = [Library.DASK in primitive.compatibility for primitive in agg_primitives]
-    agg_koalas = [Library.KOALAS in primitive.compatibility for primitive in agg_primitives]
+    agg_spark = [Library.SPARK in primitive.compatibility for primitive in agg_primitives]
     agg_df = pd.DataFrame({'name': agg_names,
                            'description': _get_descriptions(agg_primitives),
                            'dask_compatible': agg_dask,
-                           'koalas_compatible': agg_koalas,
+                           'spark_compatible': agg_spark,
                            'valid_inputs': valid_inputs,
                            'return_type': return_type})
     agg_df['type'] = 'aggregation'
 
-    columns = ['name', 'type', 'dask_compatible', 'koalas_compatible', 'description', 'valid_inputs', 'return_type']
+    columns = ['name', 'type', 'dask_compatible', 'spark_compatible', 'description', 'valid_inputs', 'return_type']
     return pd.concat([agg_df, transform_df], ignore_index=True)[columns]
 
 
