@@ -9,7 +9,7 @@ import pandas as pd
 import pytest
 import woodwork.type_sys.type_system as ww_type_system
 from woodwork.logical_types import Datetime, LogicalType, Ordinal
-from woodwork.serialize import typing_info_to_dict
+from woodwork.serializers.serializer_base import typing_info_to_dict
 from woodwork.type_sys.utils import list_logical_types
 
 from featuretools.entityset import EntitySet, deserialize, serialize
@@ -89,7 +89,7 @@ def test_to_csv(es, tmpdir):
     assert type(new_df['latlong'][0]) in (tuple, list)
 
 
-# Dask/Koalas don't support auto setting of interesting values with es.add_interesting_values()
+# Dask/Spark don't support auto setting of interesting values with es.add_interesting_values()
 def test_to_csv_interesting_values(pd_es, tmpdir):
     pd_es.add_interesting_values()
     pd_es.to_csv(str(tmpdir))
@@ -105,7 +105,7 @@ def test_to_csv_manual_interesting_values(es, tmpdir):
     assert new_es['log'].ww['product_id'].ww.metadata['interesting_values'] == ['coke_zero']
 
 
-# Dask/Koalas do not support to_pickle
+# Dask/Spark do not support to_pickle
 def test_to_pickle(pd_es, tmpdir):
     pd_es.to_pickle(str(tmpdir))
     new_es = deserialize.read_entityset(str(tmpdir))
@@ -120,13 +120,13 @@ def test_to_pickle_errors_dask(dask_es, tmpdir):
         dask_es.to_pickle(str(tmpdir))
 
 
-def test_to_pickle_errors_koalas(ks_es, tmpdir):
+def test_to_pickle_errors_spark(spark_es, tmpdir):
     msg = 'DataFrame type not compatible with pickle serialization. Please serialize to another format.'
     with pytest.raises(ValueError, match=msg):
-        ks_es.to_pickle(str(tmpdir))
+        spark_es.to_pickle(str(tmpdir))
 
 
-# Dask/Koalas do not support to_pickle
+# Dask/Spark do not support to_pickle
 def test_to_pickle_interesting_values(pd_es, tmpdir):
     pd_es.add_interesting_values()
     pd_es.to_pickle(str(tmpdir))
@@ -134,7 +134,7 @@ def test_to_pickle_interesting_values(pd_es, tmpdir):
     assert pd_es.__eq__(new_es, deep=True)
 
 
-# Dask/Koalas do not support to_pickle
+# Dask/Spark do not support to_pickle
 def test_to_pickle_manual_interesting_values(pd_es, tmpdir):
     pd_es.add_interesting_values(dataframe_name='log', values={'product_id': ['coke_zero']})
     pd_es.to_pickle(str(tmpdir))
@@ -161,7 +161,7 @@ def test_to_parquet_manual_interesting_values(es, tmpdir):
     assert new_es['log'].ww['product_id'].ww.metadata['interesting_values'] == ['coke_zero']
 
 
-# Dask/Koalas don't support auto setting of interesting values with es.add_interesting_values()
+# Dask/Spark don't support auto setting of interesting values with es.add_interesting_values()
 def test_to_parquet_interesting_values(pd_es, tmpdir):
     pd_es.add_interesting_values()
     pd_es.to_parquet(str(tmpdir))
@@ -207,7 +207,7 @@ def make_public(s3_client, s3_bucket):
     s3_client.ObjectAcl(BUCKET_NAME, obj).put(ACL='public-read-write')
 
 
-# TODO: tmp file disappears after deserialize step, cannot check equality with Dask, Koalas
+# TODO: tmp file disappears after deserialize step, cannot check equality with Dask, Spark
 @pytest.mark.parametrize("profile_name", [None, False])
 def test_serialize_s3_csv(es, s3_client, s3_bucket, profile_name):
     if es.dataframe_type != Library.PANDAS.value:
@@ -218,7 +218,7 @@ def test_serialize_s3_csv(es, s3_client, s3_bucket, profile_name):
     assert es.__eq__(new_es, deep=True)
 
 
-# Dask and Koalas do not support to_pickle
+# Dask and Spark do not support to_pickle
 @pytest.mark.parametrize("profile_name", [None, False])
 def test_serialize_s3_pickle(pd_es, s3_client, s3_bucket, profile_name):
     pd_es.to_pickle(TEST_S3_URL, profile_name=profile_name)
@@ -227,11 +227,11 @@ def test_serialize_s3_pickle(pd_es, s3_client, s3_bucket, profile_name):
     assert pd_es.__eq__(new_es, deep=True)
 
 
-# TODO: tmp file disappears after deserialize step, cannot check equality with Dask, Koalas
+# TODO: tmp file disappears after deserialize step, cannot check equality with Dask, Spark
 @pytest.mark.parametrize("profile_name", [None, False])
 def test_serialize_s3_parquet(es, s3_client, s3_bucket, profile_name):
     if es.dataframe_type != Library.PANDAS.value:
-        pytest.xfail('tmp file disappears after deserialize step, cannot check equality with Dask or Koalas')
+        pytest.xfail('tmp file disappears after deserialize step, cannot check equality with Dask or Spark')
     es.to_parquet(TEST_S3_URL, profile_name=profile_name)
     make_public(s3_client, s3_bucket)
     new_es = deserialize.read_entityset(TEST_S3_URL, profile_name=profile_name)
@@ -296,7 +296,7 @@ def test_serialize_subdirs_not_removed(es, tmpdir):
     test_dir = write_path.mkdir("test_dir")
     with open(str(write_path.join('data_description.json')), 'w') as f:
         json.dump('__SAMPLE_TEXT__', f)
-    if es.dataframe_type == Library.KOALAS.value:
+    if es.dataframe_type == Library.SPARK.value:
         compression = 'none'
     else:
         compression = None
@@ -367,7 +367,7 @@ def test_operations_invalidate_metadata(es):
     assert new_es.metadata is not None
     assert new_es._data_description is not None
 
-    # automatically adding interesting values not supported in Dask or Koalas
+    # automatically adding interesting values not supported in Dask or Spark
     if new_es.dataframe_type == Library.PANDAS.value:
         new_es.add_interesting_values()
         assert new_es._data_description is None
