@@ -20,12 +20,12 @@ from featuretools.primitives import Count, CumMax, Mode, NMostCommon, Year
 
 @pytest.fixture
 def simple_feat(es):
-    return IdentityFeature(es['log']['id'])
+    return IdentityFeature(es['log'].ww['id'])
 
 
 @pytest.fixture
 def trans_feat(es):
-    return TransformFeature(es['customers']['cancel_date'], Year)
+    return TransformFeature(IdentityFeature(es['customers'].ww['cancel_date']), Year)
 
 
 def test_returns_digraph_object(simple_feat):
@@ -57,11 +57,11 @@ def test_transform(es, trans_feat):
 
     feat_name = feat.get_name()
     prim_node = '0_{}_year'.format(feat_name)
-    entity_table = '\u2605 customers (target)'
+    dataframe_table = '\u2605 customers (target)'
     prim_edge = 'customers:cancel_date -> "{}"'.format(prim_node)
     feat_edge = '"{}" -> customers:"{}"'.format(prim_node, feat_name)
 
-    graph_components = [feat_name, entity_table, prim_node, prim_edge, feat_edge]
+    graph_components = [feat_name, dataframe_table, prim_node, prim_edge, feat_edge]
     for component in graph_components:
         assert component in graph
 
@@ -76,7 +76,7 @@ def test_transform(es, trans_feat):
 
 def test_html_symbols(es, tmpdir):
     output_path_template = str(tmpdir.join("test{}.png"))
-    value = IdentityFeature(es['log']['value'])
+    value = IdentityFeature(es['log'].ww['value'])
     gt = value > 5
     lt = value < 5
     ge = value >= 5
@@ -90,20 +90,20 @@ def test_html_symbols(es, tmpdir):
 
 
 def test_groupby_transform(es):
-    feat = GroupByTransformFeature(es['customers']['age'], CumMax, es['customers']['cohort'])
+    feat = GroupByTransformFeature(IdentityFeature(es['customers'].ww['age']), CumMax, IdentityFeature(es['customers'].ww['cohort']))
     graph = graph_feature(feat).source
 
     feat_name = feat.get_name()
     prim_node = "0_{}_cum_max".format(feat_name)
     groupby_node = '{}_groupby_customers--cohort'.format(feat_name)
-    entity_table = '\u2605 customers (target)'
+    dataframe_table = '\u2605 customers (target)'
 
     groupby_edge = 'customers:cohort -> "{}"'.format(groupby_node)
     groupby_input = 'customers:age -> "{}"'.format(groupby_node)
     prim_input = '"{}" -> "{}"'.format(groupby_node, prim_node)
     feat_edge = '"{}" -> customers:"{}"'.format(prim_node, feat_name)
 
-    graph_components = [feat_name, prim_node, groupby_node, entity_table,
+    graph_components = [feat_name, prim_node, groupby_node, dataframe_table,
                         groupby_edge, groupby_input, prim_input, feat_edge]
     for component in graph_components:
         assert component in graph
@@ -112,15 +112,15 @@ def test_groupby_transform(es):
     assert len(matches) == 1
     rows = re.findall(r"<TR.*?</TR>", matches[0], re.DOTALL)
     assert len(rows) == 4
-    assert entity_table in rows[0]
+    assert dataframe_table in rows[0]
     assert feat_name in rows[-1]
     assert ('age' in rows[1] and 'cohort' in rows[2]) or \
            ('age' in rows[2] and 'cohort' in rows[1])
 
 
 def test_groupby_transform_direct_groupby(es):
-    groupby = DirectFeature(es['cohorts']['cohort_name'], es['customers'])
-    feat = GroupByTransformFeature(es['customers']['age'], CumMax, groupby)
+    groupby = DirectFeature(IdentityFeature(es['cohorts'].ww['cohort_name']), 'customers')
+    feat = GroupByTransformFeature(IdentityFeature(es['customers'].ww['age']), CumMax, groupby)
     graph = graph_feature(feat).source
 
     groupby_name = groupby.get_name()
@@ -145,28 +145,28 @@ def test_groupby_transform_direct_groupby(es):
     for component in graph_components:
         assert component in graph
 
-    entities = {'cohorts': [cohorts_table, 'cohort_name'],
-                'customers': [customers_table, 'cohort', 'age', groupby_name, feat_name]}
-    for entity in entities:
-        regex = r"{} \[label=<\n<TABLE.*?</TABLE>>".format(entity)
+    dataframes = {'cohorts': [cohorts_table, 'cohort_name'],
+                  'customers': [customers_table, 'cohort', 'age', groupby_name, feat_name]}
+    for dataframe in dataframes:
+        regex = r"{} \[label=<\n<TABLE.*?</TABLE>>".format(dataframe)
         matches = re.findall(regex, graph, re.DOTALL)
         assert len(matches) == 1
 
         rows = re.findall(r"<TR.*?</TR>", matches[0], re.DOTALL)
-        assert len(rows) == len(entities[entity])
+        assert len(rows) == len(dataframes[dataframe])
 
         for row in rows:
             matched = False
-            for i in entities[entity]:
+            for i in dataframes[dataframe]:
                 if i in row:
                     matched = True
-                    entities[entity].remove(i)
+                    dataframes[dataframe].remove(i)
                     break
             assert matched
 
 
 def test_aggregation(es):
-    feat = AggregationFeature(es['log']['id'], es['sessions'], Count)
+    feat = AggregationFeature(IdentityFeature(es['log'].ww['id']), 'sessions', Count)
     graph = graph_feature(feat).source
 
     feat_name = feat.get_name()
@@ -187,27 +187,27 @@ def test_aggregation(es):
     for component in graph_components:
         assert component in graph
 
-    entities = {'log': [log_table, 'id', 'session_id'],
-                'sessions': [sessions_table, feat_name]}
-    for entity in entities:
-        regex = r"{} \[label=<\n<TABLE.*?</TABLE>>".format(entity)
+    dataframes = {'log': [log_table, 'id', 'session_id'],
+                  'sessions': [sessions_table, feat_name]}
+    for dataframe in dataframes:
+        regex = r"{} \[label=<\n<TABLE.*?</TABLE>>".format(dataframe)
         matches = re.findall(regex, graph, re.DOTALL)
         assert len(matches) == 1
 
         rows = re.findall(r"<TR.*?</TR>", matches[0], re.DOTALL)
-        assert len(rows) == len(entities[entity])
+        assert len(rows) == len(dataframes[dataframe])
         for row in rows:
             matched = False
-            for i in entities[entity]:
+            for i in dataframes[dataframe]:
                 if i in row:
                     matched = True
-                    entities[entity].remove(i)
+                    dataframes[dataframe].remove(i)
                     break
             assert matched
 
 
 def test_multioutput(es):
-    multioutput = AggregationFeature(es['log']['zipcode'], es['sessions'], NMostCommon)
+    multioutput = AggregationFeature(IdentityFeature(es['log'].ww['zipcode']), 'sessions', NMostCommon)
     feat = FeatureOutputSlice(multioutput, 0)
     graph = graph_feature(feat).source
 
@@ -229,28 +229,28 @@ def test_multioutput(es):
     for component in graph_components:
         assert component in graph
 
-    entities = {'log': [log_table, 'zipcode', 'session_id'],
-                'sessions': [sessions_table, feat_name]}
-    for entity in entities:
-        regex = r"{} \[label=<\n<TABLE.*?</TABLE>>".format(entity)
+    dataframes = {'log': [log_table, 'zipcode', 'session_id'],
+                  'sessions': [sessions_table, feat_name]}
+    for dataframe in dataframes:
+        regex = r"{} \[label=<\n<TABLE.*?</TABLE>>".format(dataframe)
         matches = re.findall(regex, graph, re.DOTALL)
         assert len(matches) == 1
 
         rows = re.findall(r"<TR.*?</TR>", matches[0], re.DOTALL)
-        assert len(rows) == len(entities[entity])
+        assert len(rows) == len(dataframes[dataframe])
         for row in rows:
             matched = False
-            for i in entities[entity]:
+            for i in dataframes[dataframe]:
                 if i in row:
                     matched = True
-                    entities[entity].remove(i)
+                    dataframes[dataframe].remove(i)
                     break
             assert matched
 
 
 def test_direct(es):
-    d1 = DirectFeature(es['customers']['engagement_level'], es['sessions'])
-    d2 = DirectFeature(d1, es['log'])
+    d1 = DirectFeature(IdentityFeature(es['customers'].ww['engagement_level']), 'sessions')
+    d2 = DirectFeature(d1, 'log')
     graph = graph_feature(d2).source
 
     d1_name = d1.get_name()
@@ -275,29 +275,29 @@ def test_direct(es):
     for component in graph_components:
         assert component in graph
 
-    entities = {'customers': [customers_table, 'engagement_level'],
-                'sessions': [sessions_table, 'customer_id', d1_name],
-                'log': [log_table, 'session_id', d2_name]}
+    dataframes = {'customers': [customers_table, 'engagement_level'],
+                  'sessions': [sessions_table, 'customer_id', d1_name],
+                  'log': [log_table, 'session_id', d2_name]}
 
-    for entity in entities:
-        regex = r"{} \[label=<\n<TABLE.*?</TABLE>>".format(entity)
+    for dataframe in dataframes:
+        regex = r"{} \[label=<\n<TABLE.*?</TABLE>>".format(dataframe)
         matches = re.findall(regex, graph, re.DOTALL)
         assert len(matches) == 1
 
         rows = re.findall(r"<TR.*?</TR>", matches[0], re.DOTALL)
-        assert len(rows) == len(entities[entity])
+        assert len(rows) == len(dataframes[dataframe])
         for row in rows:
             matched = False
-            for i in entities[entity]:
+            for i in dataframes[dataframe]:
                 if i in row:
                     matched = True
-                    entities[entity].remove(i)
+                    dataframes[dataframe].remove(i)
                     break
             assert matched
 
 
 def test_stacked(es, trans_feat):
-    stacked = AggregationFeature(trans_feat, es['cohorts'], Mode)
+    stacked = AggregationFeature(trans_feat, 'cohorts', Mode)
     graph = graph_feature(stacked).source
 
     feat_name = stacked.get_name()
