@@ -3,7 +3,7 @@ import pandas as pd
 
 from featuretools.utils.gen_utils import import_or_none, is_instance
 
-ks = import_or_none('databricks.koalas')
+ps = import_or_none('pyspark.pandas')
 
 
 def to_pandas(df, index=None, sort_index=False, int_index=False):
@@ -23,7 +23,7 @@ def to_pandas(df, index=None, sort_index=False, int_index=False):
 
     if isinstance(df, (dd.DataFrame, dd.Series)):
         pd_df = df.compute()
-    if is_instance(df, (ks, ks), ('DataFrame', 'Series')):
+    if is_instance(df, (ps, ps), ('DataFrame', 'Series')):
         pd_df = df.to_pandas()
 
     if index:
